@@ -56,7 +56,7 @@ static char ripe_server[] = "whois.ripe.net";
 static char ripe_ris_server[] = "riswhois.ripe.net";
 
 #ifdef STANDALONE
-const char *version = "3.75";                    /* set version string for library and client */
+const char *version = "3.76";                    /* set version string for library and client */
 const char *appname = "WhoB";            	    /* set application name */
 static int go_interactive = 0;                  /* We'll wait on STDIN unless args suggest otherwise */
 static int use_cymru = 0;                       /* Don't use Cymru by default */
@@ -1535,7 +1535,7 @@ w_lookup_all_pwhois_bulk(whois_session_params * wsess, struct ip_list_array *ipl
     if (!iplist)
         return -1;
     
-    if ((*iplist).application) {
+    if ((uintptr_t)(*iplist).application) {
         bulk_ip_query = (char *)malloc(((strlen((*iplist).application) * sizeof(char)) +10) + ((strlen(bulk_begin) + strlen(bulk_end) + 1) * sizeof(char)) + (16 * (*iplist).numItems));
     } else 
 	bulk_ip_query = (char *)malloc(((strlen(appname) * sizeof(char)) +10) + ((strlen(version) + strlen(bulk_begin) + strlen(bulk_end) + 1) * sizeof(char)) + (16 * (*iplist).numItems));
@@ -1550,7 +1550,7 @@ w_lookup_all_pwhois_bulk(whois_session_params * wsess, struct ip_list_array *ipl
     
     /* prepare the text-string-based query */
     strcat(bulk_ip_query,bulk_begin);
-    if ((*iplist).application) {
+    if ((uintptr_t)(*iplist).application) {
         strcat(bulk_ip_query, "app=\"");
         strcat(bulk_ip_query, (*iplist).application);
         strcat(bulk_ip_query, "\"\n");
@@ -1655,7 +1655,7 @@ w_lookup_all_pwhois_bulk_ext(whois_session_params * wsess, struct ext_ip_list_ar
         return -1;
     iplist->geoavailable=0;
 
-    if ((*iplist).application) {
+    if ((uintptr_t)(*iplist).application) {
         bulk_ip_query = malloc(((strlen((*iplist).application) * sizeof(char)) +10) + ((strlen(bulk_begin) + strlen(bulk_end) + 1) * sizeof(char)) + (16 * (*iplist).numItems));
     } else bulk_ip_query = malloc(((strlen(appname) * sizeof(char)) +10) + ((strlen(version) + strlen(bulk_begin) + strlen(bulk_end) + 1) * sizeof(char)) + (16 * (*iplist).numItems));
     bulk_ip_query[0]=0;
@@ -1669,7 +1669,7 @@ w_lookup_all_pwhois_bulk_ext(whois_session_params * wsess, struct ext_ip_list_ar
     
     /* prepare the text-string-based query */
     strcat(bulk_ip_query,bulk_begin);
-    if ((*iplist).application) {
+    if ((uintptr_t)(*iplist).application) {
         strcat(bulk_ip_query,"app=\"");
         strcat(bulk_ip_query,(*iplist).application);
         strcat(bulk_ip_query,"\"\n");
